//公用饼图
import DotText from "@/components/DotText";
// import EmptySpace from '@/components/EmptySpace';
import { Flex } from "antd";
import classNames from "classnames";
import { CSSProperties } from "react";
import Chart from "./Chart";
import styles from "./index.less";
interface PieChartDto {
  data?: API.BaseChartInfo[]; //数据源
  labelGap?: number; //label间距
  style?: CSSProperties; //样式
  chartStyle?: CSSProperties; //chartStyle样式
  labelClassName?: string; //label样式
  color?: string[]; //颜色
  vertical?: boolean;
  chartOptions?: any;
}
const PieChart: React.FC<PieChartDto> = ({
  style,
  labelGap = 8,
  chartStyle = { width: "260px", height: "300px" },
  data = [],
  labelClassName,
  color = ["#ff9b5d", "#2ab5ff", "#ffd28e", "#B5B4FF", "#B5B42F"],
  vertical,
  chartOptions,
}) => {
  return (
    <Flex style={{ ...style }} align="center" vertical={vertical}>
      {data.length > 0 ? (
        <>
          
            <Chart
              data={data}
              color={color}
              style={{ ...chartStyle }}
              options={chartOptions}
            />
       

          <div className={styles.label} style={{ gap: labelGap }}>
            {data.map((it, index) => (
              <Flex
                align="center"
                justify="space-between"
                key={it.name}
                className={classNames(styles.labelItem, labelClassName)}
              >
                <DotText dotcolor={color[index]} title={it.name} />

                {it?.percent && (
                  <span>
                    <b>{parseFloat(Number(it.percent).toFixed(1))}</b>%
                  </span>
                )}
                <span className={styles.valueWrap}>
                  <b>{it.value}</b>
                </span>
              </Flex>
            ))}
          </div>
        </>
      ) : (
        // <EmptySpace describe="暂无数据" style={{ height: '160px' }} />
        <span>暂无数据</span>
      )}
    </Flex>
  );
};
export default PieChart;
