import { useLocation, useNavigate } from "umi";
import styles from "./index.less";
import { useEffect, useLayoutEffect, useState } from "react";

const menu = [
  {
    title: "总体态势",
    unActiveIcon: require("@/assets/images/sidebar/ztts_ua.png"),
    activeIcon: require("@/assets/images/sidebar/ztts_a.png"),
    path: "/home/overall",
  },
  {
    title: "环卫固废",
    unActiveIcon: require("@/assets/images/sidebar/hwgf_ua.png"),
    activeIcon: require("@/assets/images/sidebar/hwgf_a.png"),
    path: "/home/solidWaste",
  },
  {
    title: "市政设施",
    unActiveIcon: require("@/assets/images/sidebar/szss_ua.png"),
    activeIcon: require("@/assets/images/sidebar/szss_a.png"),
    path: "/home/municipalFacilities",
  },
  {
    title: "市容广告",
    unActiveIcon: require("@/assets/images/sidebar/srgg_ua.png"),
    activeIcon: require("@/assets/images/sidebar/srgg_a.png"),
    path: "/home/advertisement",
  },
  {
    title: "行政执法",
    unActiveIcon: require("@/assets/images/sidebar/xzzf_ua.png"),
    activeIcon: require("@/assets/images/sidebar/xzzf_a.png"),
    path: "/home/administrativeLawEnforcement",
  },
  {
    title: "监督考评",
    unActiveIcon: require("@/assets/images/sidebar/jdkp_ua.png"),
    activeIcon: require("@/assets/images/sidebar/jdkp_a.png"),
    path: "/home/supervisionAndEvaluation",
  },
  {
    title: "综合指挥",
    unActiveIcon: require("@/assets/images/sidebar/zhzh_ua.png"),
    activeIcon: require("@/assets/images/sidebar/zhzh_a.png"),
    path: "/home/integratedCommand",
  },
];
/** @name 侧边栏目录 */
export default function SidebarMenu() {
  const [active, setActive] = useState(0);
  const location = useLocation();

  const navigation = useNavigate();

  useLayoutEffect(() => {
    const activeIndex = menu.findIndex(
      (item) => item.path === location.pathname
    );
    if (activeIndex !== active) {
      setActive(activeIndex);
    }
  }, []);

  const menuClickHandle = (index: number, item: (typeof menu)[0]) => {
    setActive(index);
    navigation(item.path);
  };
  return (
    <div className={styles.container}>
      {menu.map((item, i) => (
        <div key={item.title} onClick={() => menuClickHandle(i, item)}>
          <img
            src={i === active ? item.activeIcon : item.unActiveIcon}
            alt=""
          />
          <div
            className={styles.menuItem_title}
            style={
              i === active
                ? { color: "rgb(43, 133, 255)", fontWeight: "700" }
                : { color: "#000" }
            }
          >
            {item.title}
          </div>
        </div>
      ))}
    </div>
  );
}
