import React, { useRef, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";
import NormalcyLawModal, { CleanRangeModalMethod } from "../NormalcyLawModal";
import SpecialLawModal from "../SpecialLawModal";
import IllegalBuildingModal from "../IllegalBuildingModal";
import SuperintendModal from "../SuperintendModal";

interface DomainEventSituationDistributionProps {
  data?: any;
  loading?: boolean;
}

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC<DomainEventSituationDistributionProps> = ({ data }) => {
  const [curLocation, setCurLocation] = useState<"today">("today");
  const normalcyLawRef = useRef<CleanRangeModalMethod>(null);
  const specialLawRef = useRef<CleanRangeModalMethod>(null);
  const illegalBuildingLawRef = useRef<CleanRangeModalMethod>(null);
  const superintendRef = useRef<CleanRangeModalMethod>(null);

  const menu = [
    {
      name: "常态执法",
      value: data?.normalLaw?.count || 0,
      icon: require("@/assets/images/administrativeLawEnforcement/ctzfIc.png"),
      onClick: () => {
        normalcyLawRef.current?.show();
      },
    },
    {
      name: "专项执法",
      value: data?.specialLaw?.count || 0,
      icon: require("@/assets/images/administrativeLawEnforcement/zhuanxianzhifaIc.png"),
      onClick: () => {
        specialLawRef.current?.show();
      },
    },
    {
      name: "违建治理",
      value: data?.illegalBuilding?.count || 0,
      icon: require("@/assets/images/administrativeLawEnforcement/weijianIc.png"),
      onClick: () => {
        illegalBuildingLawRef.current?.show();
      },
    },
    {
      name: "执法督察",
      value: data?.supervision?.count || 0,
      icon: require("@/assets/images/administrativeLawEnforcement/duchaIc.png"),
      onClick: () => {
        superintendRef.current?.show();
      },
    },
  ];

  return (
    <div className={styles.container}>
      <NormalcyLawModal ref={normalcyLawRef} data={data?.normalLaw?.details} />
      <SpecialLawModal ref={specialLawRef} data={data?.specialLaw?.details} />
      <IllegalBuildingModal ref={illegalBuildingLawRef} data={data?.illegalBuilding?.details} />
      <SuperintendModal ref={superintendRef} data={data?.supervision?.details} />
      
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>领域事件态势分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      
      <Flex gap={35} className={styles.listWrap}>
        {menu.map((item, index) => (
          <div
            className={styles.GradientBorder}
            key={index}
            onClick={item.onClick}
          >
            <div className={styles.itemCard}>
              <Space>
                <div className={styles.itemVal}>{item.value}</div>
                <div className={styles.itemUnit}>件</div>
              </Space>
              <div className={styles.itemName}>{item.name}</div>
              <div className={styles.itemImgWrap}>
                <img src={item.icon} alt="" />
              </div>
            </div>
          </div>
        ))}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
