import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import PieChart from "@/components/PieChart";
import FacilityInfoCard from "@/pages/MunicipalFacilities/components/PipeModal/components/FacilityInfoCard";

interface SuperintendModalProps {
  data?: any;
}

interface CardProps {
  title?: React.ReactNode;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const SuperintendModal = forwardRef<CleanRangeModalMethod, SuperintendModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="执法督察"
        onCancel={action.setFalse}
        width={991}
      >
        <div className={styles.content}>
          <Card
            w={526}
            h={400}
            title={
              <div>
                本月执法督察案件总数
                <span
                  style={{
                    color: "rgb(57, 136, 250)",
                    fontSize: 26,
                    fontWeight: 700,
                    marginLeft: 5,
                    marginRight: 5,
                  }}
                >
                  {data?.totalCases || 0}
                </span>
                件
              </div>
            }
          >
            <PieChart
              style={{ width: "100%" }}
              chartStyle={{ width: 166, height: 166 }}
              labelGap={22}
              labelClassName={styles.labelClassName}
              data={data?.caseTypes || []}
            />
          </Card>
          <div>
            <Card w={384} h={195} title="督察反馈情况">
              <div className={styles.zlWarp}>
                <FacilityInfoCard
                  style={{ height: 90, width: 149 }}
                  data={{
                    count: data?.feedback?.completed || 0,
                    unit: "件",
                    label: "已反馈"
                  }}
                />
                <FacilityInfoCard
                  style={{ height: 90, width: 149 }}
                  data={{
                    count: data?.feedback?.pending || 0,
                    unit: "件",
                    label: "待反馈"
                  }}
                />
              </div>
            </Card>
            <Card
              w={384}
              h={195}
              title="整改情况"
              style={{ marginTop: 10 }}
            >
              <div className={styles.zlWarp}>
                <FacilityInfoCard
                  style={{ height: 90, width: 149 }}
                  data={{
                    count: data?.rectification?.completed || 0,
                    unit: "件",
                    label: "已整改"
                  }}
                />
                <FacilityInfoCard
                  style={{ height: 90, width: 149 }}
                  data={{
                    count: data?.rectification?.pending || 0,
                    unit: "件",
                    label: "待整改"
                  }}
                />
              </div>
            </Card>
          </div>
        </div>
      </BaseModal>
    </div>
  );
});

export default SuperintendModal;
