import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import MaintainCompany from "./components/MaintainCompany";
import RoadInfoCard from "@/pages/MunicipalFacilities/components/RoadModal/components/RoadInfoCard";
import ProgressBar from "@/pages/MunicipalFacilities/components/PipeModal/components/ProgressBar";

interface BikeSharingModalProps {
  data?: any;
}

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const BikeSharingModal = forwardRef<CleanRangeModalMethod, BikeSharingModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="共享单车"
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <RoadInfoCard
                style={{ width: "100%" }}
                data={{
                  label: "当前全市共享单车总体数量",
                  count: data?.basicInfo?.totalBikes || 0,
                  unit: "辆"
                }}
              />

              <div className={styles.leftButtomWarp}>
                <Card title="区域分布" w={428} h={643}>
                  <div>单位：公里</div>
                  <div className={styles.detailContent}>
                    {(data?.areaDistribution || []).map((item: any, index: number) => (
                      <div className={styles.areaItem} key={index}>
                        <span style={{ marginRight: 40 }}>{item.name}</span>
                        <ProgressBar value={item.value} total={item.total} />
                      </div>
                    ))}
                  </div>
                </Card>
                <Card title="维护单位" style={{ marginLeft: 20 }} w={428} h={643}>
                  <MaintainCompany data={data?.maintenanceUnits || []} />
                </Card>
              </div>
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default BikeSharingModal;
