import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import ProgressBar from "../PipeModal/components/ProgressBar";
import MaintainCompany from "./components/MaintainCompany";
import PipeInfoCard from "../PipeModal/components/PipeInfoCard";
import RoadInfoCard from "../RoadModal/components/RoadInfoCard";
import RealTimeStatusCard from "./components/RealTimeStatusCard";

interface LightingModalProps {
  data?: any;
}

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const LightingModal = forwardRef<CleanRangeModalMethod, LightingModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="照明设施"
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <div className={styles.leftTopWarp}>
                <PipeInfoCard
                  showRignt={false}
                  data={{
                    label: "全市道路照明灯盏数",
                    count: data?.basicInfo?.totalLights || 0,
                    unit: "盏"
                  }}
                />
                <div>
                  <RoadInfoCard
                    data={{
                      label: "全市LED光源灯盏数",
                      count: data?.basicInfo?.ledLights || 0,
                      unit: "盏"
                    }}
                    style={{ width: 381, height: 45, marginBottom: 10 }}
                  />
                  <RoadInfoCard
                    style={{ width: 381, height: 45 }}
                    data={{
                      label: "全市传统光源灯盏数",
                      count: data?.basicInfo?.traditionalLights || 0,
                      unit: "盏"
                    }}
                  />
                </div>
                <RealTimeStatusCard 
                  normal={data?.status?.normal || 0}
                  fault={data?.status?.fault || 0}
                />
              </div>

              <div className={styles.leftButtomWarp}>
                <Card title="区域分布情况" w={428} h={643}>
                  <div>单位：公里</div>
                  <div className={styles.detailContent}>
                    {(data?.areaDistribution || []).map((item: any, index: number) => (
                      <div className={styles.areaItem} key={index}>
                        <span style={{ marginRight: 40 }}>{item.name}</span>
                        <ProgressBar value={item.value} total={item.total} />
                      </div>
                    ))}
                  </div>
                </Card>

                <Card title="维护单位" style={{ marginLeft: 20 }} w={428} h={643}>
                  <MaintainCompany data={data?.maintenanceUnits || []} />
                </Card>
              </div>
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default LightingModal;
