import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import ProgressBar from "./components/ProgressBar";
import PipeInfoCard from "./components/PipeInfoCard";
import FacilityInfoCard from "./components/FacilityInfoCard";
import { CSSProperties } from "react";

interface PipeModalProps {
  data?: any;
}

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

const PipeModal = forwardRef<CleanRangeModalMethod, PipeModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="管廊"
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <div className={styles.leftTopWarp}>
                <PipeInfoCard
                  data={{
                    label: "全市在建综合管廊",
                    count: data?.basicInfo?.totalLength1 || 0,
                    unit: "条",
                    rCount: data?.basicInfo?.completedLength1 || 0,
                    rUnit: "余公里"
                  }}
                />
                <PipeInfoCard
                  data={{
                    label: "已投运",
                    count: data?.basicInfo?.totalLength2 || 0,
                    unit: "条",
                    rCount: data?.basicInfo?.completedLength2 || 0,
                    rUnit: "余公里",
                  }}
                />{" "}
                <PipeInfoCard
                  data={{
                    label: "移交纳入管理管廊",
                    count: data?.basicInfo?.totalLength3 || 0,
                    unit: "条",
                    rCount: data?.basicInfo?.completedLength3 || 0,
                    rUnit: "余公里",
                  }}
                />
                <PipeInfoCard
                  data={{
                    label: "运维单位",
                    count: data?.basicInfo?.totalLength4 || 0,
                    unit: "条",
                    rCount: data?.basicInfo?.completedLength4 || 0,
                    rUnit: "余公里",
                  }}
                  // showRignt={false}
                />
              </div>
              
              <div className={styles.leftButtomWarp}>
                <Card title={"移交纳入管理管廊区域分布情况"} w={428} h={643}>
                  <div>单位：公里</div>
                  <div className={styles.detailContent}>
                    {(data?.areaDistribution || []).map((item: any, index: number) => (
                        <div className={styles.areaItem} key={index}>
                          <span style={{ marginRight: 40 }}>{item.name}</span>
                          <ProgressBar value={item.value} total={item.total} />
                        </div>
                      ))}
                  </div>
                </Card>
                <Card
                  title={"管廊感知设备数量"}
                  style={{ marginLeft: 20 }}
                  w={428}
                  h={643}
                >
                  <div className={styles.facilityInfoWarp}>
                    {(data?.facilityInfo || []).map((item: any, index: number) => (
                        <FacilityInfoCard key={index} data={item} />
                    ))}
                  </div>
                </Card>
              </div>

            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default PipeModal;
