import React, { CSSProperties, forwardRef, PropsWithChildren, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import ProgressBar from "../PipeModal/components/ProgressBar";
import RoadInfoCard from "./components/RoadInfoCard";
import MaintainCompany from "./components/MaintainCompany";

interface RoadModalProps {
  data?: any;
}

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};


interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: CSSProperties;
  className?: string;
}
const Card: React.FC<PropsWithChildren<CardProps>> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

const RoadModal = forwardRef<CleanRangeModalMethod, RoadModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="道路"
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>              
              <div className={styles.leftTopWarp}>
                <RoadInfoCard data={{
                  label: "总体数量",
                  count: data?.basicInfo?.numberLength || 0,
                  unit: "条",
                }}/> <RoadInfoCard data={{
                  label: "总体数量",
                  count: data?.basicInfo?.totalLength || 0,
                  unit: "公里",
                }}/>
              </div>

              <div className={styles.leftButtomWarp}>
                <Card title="区域分布情况" w={428} h={643}>
                  <div>单位：公里</div>
                  <div className={styles.detailContent}>
                    {(data?.areaDistribution || []).map((item: any, index: number) => (
                      <div className={styles.areaItem} key={index}>
                        <span style={{ marginRight: 40 }}>{item.name}</span>
                        <ProgressBar value={item.value} total={item.total} />
                      </div>
                    ))}
                  </div>
                </Card>
                
                <Card
                  title={"维护单位"}
                  style={{ marginLeft: 20 }}
                  w={428}
                  h={643}
                >
                  <MaintainCompany data={data?.maintenanceUnits || []} />
                </Card>
              </div>
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default RoadModal;
