import React, { useEffect, useState } from "react";
import styles from "./index.less";
import { Flex, Space, Tooltip } from "antd";
import BaseDesc from "@/components/BaseDesc";
import services from "@/services";

/** @name 影响因素top3 */
const FactorTop3: React.FC = () => {
  const [dataSource, setDataSource] = useState<any[]>([]);

  useEffect(() => {
    services.overall.getListTopNItems().then((res) => {
      if (res.code === 200) {
        setDataSource(res.data);
      }
    });
  }, []);

  const renderListItem = (data: any, index: number) => {
    const colors = ["#FF5050", "#FF6C2A", "#FFBB39"];

    return (
      <div className={styles.listItem} key={index}>
        <Flex justify="space-between" align="center">
          <Space>
            <div
              style={{ backgroundColor: colors[index] }}
              className={styles.rank}
            >
              {index + 1}
            </div>
            <div style={{ width: 180 }}>
              <Tooltip title={data.conditionName}>
                <div className={styles.itemTitle}>{data.conditionName}</div>
              </Tooltip>

              <div className={styles.itemDesc}>{data.fullName}</div>
            </div>
          </Space>
          <Space size={36}>
            <BaseDesc
              value={Number(data.weight).toFixed(1)}
              name="影响占比"
              unit="%"
            ></BaseDesc>
            <BaseDesc value={data.count} name="问题数量" unit="件"></BaseDesc>
            <BaseDesc
              value={Number(data.deduction).toFixed(2)}
              name="体征扣分"
              unit=""
            ></BaseDesc>
          </Space>
        </Flex>
      </div>
    );
  };
  return (
    <div className={styles.container}>
      <div className={styles.title}>CQI影响体征TOP3</div>
      {dataSource.map((item, index) => renderListItem(item, index))}
    </div>
  );
};

export default FactorTop3;
