import React, { useEffect, useMemo, useState } from "react";
import styles from "./index.less";
import { Flex, Space } from "antd";
import classNames from "classnames";
import { getColorByIndex } from "@/utils/ui";
import services from "@/services";

/** @name 区域分布 */
const RegionalDistribution: React.FC = () => {
  const [curLocation, setCurLocation] = useState<"forward" | "back">("forward");
  const [dataSource, setDataSource] = useState<any>({});
  useEffect(() => {
    services.overall.getRegionalDistribution().then((res) => {
      if (res.code === 200) {
        setDataSource(res.data);
      }
    });
  }, []);
  const barProgress = (value: number, color: string) => {
    return (
      <>
        <div className={styles.barValue} style={{ color: color }}>
          {value}
        </div>
        <div className={styles.progress}>
          <div
            className={styles.bar}
            style={{ height: `${value}%`, backgroundColor: color }}
          ></div>
        </div>
      </>
    );
  };

  const data = useMemo(() => {
    if (curLocation === "forward") {
      return dataSource?.front ?? [];
    }
    return dataSource?.after ?? [];
  }, [curLocation, dataSource]);

  return (
    <div className={styles.container}>
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>区域CQI分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "forward" && styles.select
            )}
            onClick={() => setCurLocation("forward")}
          >
            前5
          </div>
          <div
            className={classNames(
              styles.radio,
              curLocation === "back" && styles.select
            )}
            onClick={() => setCurLocation("back")}
          >
            后5
          </div>
        </Space>
      </Flex>
      <Flex
        align="center"
        justify="space-evenly"
        className={styles.barContainer}
      >
        {data.map((item: any, index: number) => {
          return (
            <div key={index} className={styles.barItem}>
              {barProgress(
                Number(item.cqi),
                getColorByIndex(Number(item.cqi))!
              )}
              <div className={styles.barChartLabel}>{item.objectName}</div>
            </div>
          );
        })}
      </Flex>
    </div>
  );
};

export default RegionalDistribution;
