import { useEffect, useMemo, useState } from "react";
import ReactECharts from "echarts-for-react";
import * as echarts from "echarts";
import styles from "./index.less";
import { Flex } from "antd";
import { gaugeOption, lineOption } from "./option";
import { getColorByIndex } from "@/utils/ui";
import BaseModal from "@/components/BaseModal";
import ModalContent from "@/components/ModalContent";
import services from "@/services";
import { cloneDeep } from "lodash";

/** @name 今日CQI */
const TodayCQI = () => {
  const [visible, setVisible] = useState(false);
  const [selectItem, setSelectItem] = useState<any>();
  const [dataSource, setDataSource] = useState<any>();

  const newGaugeOption = useMemo(() => {
    const value = dataSource?.currentIndex?.cqi ?? 0;
    const temp = cloneDeep(gaugeOption) as any;

    temp.series[0].data[0].value = Number(value);
    return temp;
  }, [dataSource]);

  const newLineOption = useMemo(() => {
    const list = dataSource?.indexDataList ?? [];

    const seriesData = list.map((item: any) => ({
      name: item.time,
      value: Number(item.qualitySign),
    }));
    const xAxisData = list.map((item: any) => item.time);
    const temp = cloneDeep(lineOption) as any;
    temp.series[0].data = seriesData;
    temp.xAxis[0].data = xAxisData;

    return temp;
  }, [dataSource]);

  useEffect(() => {
    services.overall
      .getComparisonIndexInstance({
        physicalSignType: 1,
        indexType: 1,
        indexHierarchy: "1,2",
        objectId: 1,
      })
      .then((res) => {
        if (res.code === 200) {
          setDataSource(res.data);
        }
      });
  }, []);

  const indexData = useMemo(() => {
    const data = dataSource?.currentIndex?.indexs ?? [];

    const iconMapping = {
      "2": require("@/assets/images/overall/safe.png"),
      "133": require("@/assets/images/overall/beautiful.png"),
      "3": require("@/assets/images/overall/clean.png"),
      "5": require("@/assets/images/overall/convenience.png"),
      "4": require("@/assets/images/overall/order.png"),
    };

    const cityIndex = data.map((v: any) => {
      return {
        value: v.value,
        name: v.name,
        icon: (iconMapping as any)[v.id] ?? "",
        indexId: v?.id,
      };
    });
    return cityIndex;
  }, [dataSource]);

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>成都市今日CQI</div>
        <div className={styles.header_time}>
          更新时间 {dataSource?.currentIndex?.time}
        </div>
      </Flex>
      <Flex align="center" justify="center" className={styles.gaugeChart}>
        <ReactECharts
          style={{ width: 500, height: 150 }}
          option={newGaugeOption}
        />
        <div className={styles.chart_status}>
          {dataSource?.currentIndex.status}
        </div>
      </Flex>
      <Flex align="center" justify="center" className={styles.lineChart}>
        <ReactECharts
          style={{ width: 670, height: 80 }}
          option={newLineOption}
        />
      </Flex>
      <Flex justify="center" gap={20}>
        {indexData?.map((item: any) => {
          return (
            <Flex
              gap={12}
              align="center"
              className={styles.dimensionItemCard}
              onClick={() => {
                console.log(item);

                setVisible(true);
                setSelectItem({ ...item,qualitySign:item.value,indexName:item?.name });
              }}
            >
              <img src={item.icon} alt=""></img>
              <div>
                <div className={styles.dimensionItemCard_name}>{item.name}</div>
                <div
                  className={styles.dimensionItemCard_val}
                  style={{ color: getColorByIndex(item.value) }}
                >
                  {item.value}
                </div>
              </div>
            </Flex>
          );
        })}
      </Flex>
      <BaseModal
        open={visible}
        title={selectItem?.name}
        onCancel={() => {
          setVisible(false);
        }}
        width={1524}
      >
        {selectItem && <ModalContent item={selectItem} />}
      </BaseModal>
    </div>
  );
};

export default TodayCQI;
