import React, { useRef, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";
import GridAdminModal, { CleanRangeModalMethod } from "../GridAdminModal";
import IndustryEveryDayModal from "../IndustryEveryDayModal";
import DataCityManageModal from "../DataCityManageModal";

interface DomainEventSituationDistributionProps {
  data?: any;
  loading?: boolean;
}

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC<DomainEventSituationDistributionProps> = ({ data }) => {
  const gridAdminModalRef = useRef<CleanRangeModalMethod>(null);
  const industryEveryDayRef = useRef<CleanRangeModalMethod>(null);
  const dataCityManageRef = useRef<CleanRangeModalMethod>(null);

  const menu = [
    {
      name: (
        <img src={require('@/assets/images/supervisionAndEvaluation/textBg1.png')} alt="" />
      ),
      icon: require("@/assets/images/supervisionAndEvaluation/icon1.png"),
      onClick: () => {
        gridAdminModalRef.current?.show();
      },
    },
    {
      name: (
        <img src={require('@/assets/images/supervisionAndEvaluation/textBg2.png')} alt="" />
      ),
      icon: require("@/assets/images/supervisionAndEvaluation/icon2.png"),
      onClick: () => {
        industryEveryDayRef.current?.show();
      },
    },
    {
      name: (
        <img src={require('@/assets/images/supervisionAndEvaluation/textbg3.png')} alt="" />
      ),
      icon: require("@/assets/images/supervisionAndEvaluation/icon3.png"),
      onClick: () => {
        dataCityManageRef.current?.show();
      },
    },
  ];

  // 导出报表处理函数
  const handleExport = () => {
    message.success('导出成功');
    // TODO: 实现导出逻辑
  };

  return (
    <div className={styles.container}>
      <GridAdminModal 
        ref={gridAdminModalRef} 
        data={data?.gridManagement} 
        onExport={handleExport}
      />
      <IndustryEveryDayModal 
        ref={industryEveryDayRef} 
        data={data?.industrySupervision}
        onExport={handleExport}
      />
      <DataCityManageModal 
        ref={dataCityManageRef} 
        data={data?.digitalCityManagement}
        onExport={handleExport}
      />

      <Flex gap={35} className={styles.listWrap}>
        {menu.map((item, index) => (
          <div
            className={styles.GradientBorder}
            key={index}
            onClick={item.onClick}
          >
            <div className={styles.itemCard}>
              <div className={styles.itemName}>{item.name}</div>
              <div className={styles.itemImgWrap}>
                <img src={item.icon} alt="" />
              </div>
            </div>
          </div>
        ))}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
