import { useMemo } from "react";
import ReactECharts from "echarts-for-react";
import styles from "./index.less";
import { Flex } from "antd";
import { barOption } from "./option";
import { cloneDeep } from 'lodash';

interface SituationOverviewProps {
  data?: any;
  loading?: boolean;
}

/** @name 监督考评指数态势总览 */
const SituationOverview: React.FC<SituationOverviewProps> = ({ data }) => {
  console.log(data);
  const newBarOption = useMemo(() => {
    const areaData = data?.areaScores || [];
    const xAxisData = areaData.map((item: any) => item.name);
    const scores = areaData.map((item: any) => item.score);
    
    const temp = cloneDeep(barOption);
    (temp.series as any)[0].data = areaData.map((item: any) => ({
      value: item.score,
      itemStyle: {
        color: '#8d8dff',
      },
    }));
    (temp.xAxis as any)[0].data = xAxisData;
    (temp.xAxis as any)[1].data = scores;
    return temp;
  }, [data]);

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>监督考评指数态势总览</div>
        <div className={styles.header_time}>更新时间 {data?.time}</div>
      </Flex>

      <div className={styles.gaugeTitle}>
        成都市{data?.month || '9'}月监督考评综合评价结果
      </div>
      <div className={styles.barChart}>
        <ReactECharts
          option={newBarOption}
          style={{ width: "100%", height: 290 }}
        />
      </div>
    </div>
  );
};

export default SituationOverview;
