import React, { useEffect } from "react";
import styles from "./index.less";
import SituationOverview from "./components/SituationOverview";
import ProblemOverview from "./components/ProblemOverview";
import DomainEventSituationDistribution from "./components/DomainEventSituationDistribution";
import { useGenericData } from '@/hooks/useGenericData';
import { initializeGenericData } from '@/services/GenericData';
import { supervisionEvaluationMockData } from './mockData';

/** @name 监督考评 */
const SupervisionAndEvaluation: React.FC = () => {
  // 使用通用数据服务
  const {
    dataSource,
    loading,
    fetchData
  } = useGenericData({
    module: 'supervision-evaluation',
    type: 'overview',
    onError: (error) => {
      console.error('获取数据失败:', error);
    }
  });

  // 初始化数据
  useEffect(() => {
    const initData = async () => {
      try {
        const response = await fetchData();
        if (!(response as any)?.data?.items?.length) {
          await initializeGenericData('supervision-evaluation', 'overview', supervisionEvaluationMockData as any);
          fetchData();
        }
      } catch (error) {
        console.error('初始化数据失败:', error);
      }
    };
    initData();
  }, []);

  // 获取第一条数据
  const data = (dataSource as any)?.[0];
  console.log(data);

  return (
    <div className={styles.container}>
      <SituationOverview data={data?.situationOverview?.currentIndex} loading={loading} />
      <ProblemOverview data={data?.evaluationSummary} loading={loading} />
      <DomainEventSituationDistribution data={data?.domainEvents} loading={loading} />
    </div>
  );
};

export default SupervisionAndEvaluation;
